@@ -1,23 +1,31 @@
-/*	Copyright (C) 1993 Free Software Foundation, Inc.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this software; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+/*
+ * $Id: basic.c,v 1.20 2000/07/22 06:13:15 danny Exp $
+ *
+ * Copyright  1993, 2000 Free Software Foundation, Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this software; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifdef	WITH_DMALLOC
+#include <dmalloc.h>
+#endif
+
 #include <ctype.h>
 #include "sysdef.h"
 #include "global.h"
@@ -37,13 +45,14 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include "eval.h"
 #include "byte-compile.h"
 #include "decompile.h"
+#include "userpref.h"
 
 
 /* Used by motion commands. */
 const int colmagic[] = {0, 0, 1, -1, 1, -1, 1, -1, 0};
 const int rowmagic[] = {-1, 1, 0, 0, -1, -1, 1, 1, 0};
 
-char * motion_name[] =  
+static char * motion_name[] =  
 {
   "up",
   "down",
@@ -58,7 +67,7 @@ char * motion_name[] =
 
 
 /* This table ought to be a user parameter. */
-enum motion_magic complementary_motion[] = 
+static enum motion_magic complementary_motion[] = 
 {
   magic_right,
   magic_right,
@@ -71,7 +80,7 @@ enum motion_magic complementary_motion[] =
   magic_no_motion,
 };
 
-enum motion_magic opposite_motion[] = 
+static enum motion_magic opposite_motion[] = 
 {
   magic_down,
   magic_up,
@@ -525,7 +534,7 @@ kill_oleo (void)
 	write_file_generic(stdout, NULL, NULL);
   }
 
-  io_close_display ();
+  io_close_display(0);
   exit (0);
 }
 
@@ -566,13 +575,13 @@ goto_region (struct rng *r)
 {
   (void) io_move_cell_cursor (r->lr, r->lc);
 
-  if (r->hr != r->lr || r->hc != r->lc)
-    {
-      mkrow = r->hr;
-      mkcol = r->hc;
-    }
-  else if (mkrow != NON_ROW)
-    mkrow = NON_ROW;
+  if (r->hr != r->lr || r->hc != r->lc) {
+	mkrow = r->hr;
+	mkcol = r->hc;
+  } else if (mkrow != NON_ROW) {
+	mkrow = NON_ROW;
+  }
+
   io_update_status ();
 }
 
@@ -804,21 +813,20 @@ mark_cell_cmd (int popmk)
 	  rng.hc = NON_COL;
 	  goto_region (&rng);
 	}
-    }
-  else
-    {
-      mkrow = curow;
-      mkcol = cucol;
-      io_update_status ();
+    } else {
+	mkrow = curow;
+	mkcol = cucol;
+	io_update_status ();
     }
 }
 
 void
 unmark_cmd (void)
 {
-  mkrow = NON_ROW;
-  mkcol = NON_COL;
-  io_update_status ();
+	mkrow = NON_ROW;
+	mkcol = NON_COL;
+
+	io_update_status ();
 }
 
 void
@@ -837,7 +845,7 @@ save_mark_to_cell (struct rng * rng)
     set_rng (&r, curow, cucol, curow, cucol);
   error = new_value (row, col, backslash_a_string(range_name(&r), 1));
     if (!error)
-      modified = 1;
+      Global->modified = 1;
     else
       io_error_msg (error);
 }
@@ -856,7 +864,7 @@ save_point_to_cell (struct rng * rng)
 
   error = new_value (row, col, backslash_a_string(range_name(&r), 1));
     if (!error)
-      modified = 1;
+      Global->modified = 1;
     else
       io_error_msg (error);
 }
@@ -900,10 +908,9 @@ do_mouse_goto (void)
 void
 do_mouse_mark (void)
 {
-  if (last_mouse_event.location >= 0 && last_mouse_event.downp)
-    {
-      mkrow = last_mouse_event.r;
-      mkcol = last_mouse_event.c;
+  if (last_mouse_event.location >= 0 && last_mouse_event.downp) {
+	mkrow = last_mouse_event.r;
+	mkcol = last_mouse_event.c;
     }
 }
 
@@ -911,10 +918,9 @@ do_mouse_mark (void)
 void
 do_mouse_mark_and_goto (void)
 {
-  if (last_mouse_event.location >= 0 && last_mouse_event.downp)
-    {
-      mkrow = curow;
-      mkcol = cucol;
+  if (last_mouse_event.location >= 0 && last_mouse_event.downp) {
+	mkrow = curow;
+	mkcol = cucol;
     }
   do_mouse_goto ();
 }
@@ -964,7 +970,7 @@ kill_cell_cmd (void)
   new_value (curow, cucol, "");
   bzero(&(cp->cell_flags), sizeof(cp->cell_flags));
   cp->cell_font = 0;
-  modified = 1;
+  Global->modified = 1;
 }
 
 
@@ -1268,7 +1274,7 @@ edit_cell (char * new_formula)
   if (fail)
     io_error_msg (fail);
   else
-    modified = 1;
+    Global->modified = 1;
 }
 
 
@@ -1282,7 +1288,7 @@ set_region_formula (struct rng * rng, char * str)
       {
 	char * error = new_value (row, col, str);
 	if (!error)
-	  modified = 1;
+	  Global->modified = 1;
 	if (error)
 	  {
 	    io_error_msg (error);
@@ -1308,18 +1314,17 @@ goto_set_cell (int c)
   execute_command ("set-cell");
 }
 
-/* File i/o */
-int sneaky_linec = 0;	/* for error reporting for now (see io-term.c) */
-
 void 
 read_cmds_cmd (FILE *fp)
 {
   struct line line;
   char *ptr;
   init_line (&line);
-  sneaky_linec = 0;
-  while (read_line (&line, fp, &sneaky_linec))
-    {
+  Global->sneaky_linec = 0;
+  while (read_line (&line, fp, &Global->sneaky_linec)) {
+#if 0
+	fprintf(stderr, "RunCommand(%s)\n", line.buf);
+#endif
       for (ptr = line.buf; isspace (*ptr); ptr++);
       if (!*ptr || (*ptr == '#'))
 	continue;
@@ -1328,7 +1333,6 @@ read_cmds_cmd (FILE *fp)
 }
 
 
-int run_load_hooks = 1;
 static char load_hooks_string[] = "load_hooks";
 
 /*
@@ -1351,10 +1355,10 @@ read_file_and_run_hooks (FILE * fp, int ismerge, char * name)
 		read_file_generic(fp, ismerge, ext, name);
 	}
 
-  if (run_load_hooks)
+  if (UserPreferences.run_load_hooks)
     {
       struct var * v;
-      v = find_var (load_hooks_string, sizeof (load_hooks_string) - 1);
+      v = find_var (load_hooks_string, sizeof(load_hooks_string)-1);
       if (v && v->var_flags != VAR_UNDEF)
 	execute_command (load_hooks_string);
     }
@@ -1367,14 +1371,14 @@ read_file_and_run_hooks (FILE * fp, int ismerge, char * name)
 void
 toggle_load_hooks (int turn_on)
 {
-  if (!turn_on && run_load_hooks)
+  if (!turn_on && UserPreferences.run_load_hooks)
     {
-      run_load_hooks = 0;
+      UserPreferences.run_load_hooks = 0;
       io_info_msg ("load hooks turned off");
     }
   else
     {
-      run_load_hooks = 1;
+      UserPreferences.run_load_hooks = 1;
       io_info_msg ("load hooks turned on");
     }
 }
@@ -1384,7 +1388,7 @@ write_cmd (FILE *fp, char * name)
 {
   FileSetCurrentFileName(name ? ck_savestr (name) : 0);
   (*write_file) (fp, 0);
-  modified = 0;
+  Global->modified = 0;
 }
 
 void
@@ -1544,7 +1548,7 @@ set_region_format (struct rng * rng, int fmt)
   int precision = fmt & PREC_MASK;
 
   format_region (rng, format, -1); 
-  precision_region(rng, precision, -1);
+  precision_region(rng, precision);
 }
 
 
@@ -1684,31 +1688,29 @@ define_usr_fmt (int fmt, char * pos_h, char * neg_h, char * pos_t,
 
 /* Hmm... where should this variable *really* go? */
 
-static int auto_motion_direction = magic_down;
-
 void
 set_auto_direction (enum motion_magic magic)
 {
-  auto_motion_direction = magic;
+  Global->auto_motion_direction = magic;
   io_info_msg ("Auto-motion direction = %s.", motion_name[magic]);
 }
 
 void
 auto_move (void)
 {
-  shift_cell_cursor (auto_motion_direction, 1);
+  shift_cell_cursor (Global->auto_motion_direction, 1);
 }
 
 void
 auto_next_set (void)
 {
-  scan_cell_cursor (opposite_motion[auto_motion_direction], 1);
+  scan_cell_cursor (opposite_motion[Global->auto_motion_direction], 1);
   {
     CELL * cp = find_cell (curow, cucol);
     if (!cp || !GET_TYP(cp))
-      shift_cell_cursor (auto_motion_direction, 1);
+      shift_cell_cursor (Global->auto_motion_direction, 1);
   }
-  shift_cell_cursor (complementary_motion[auto_motion_direction], 1);
+  shift_cell_cursor (complementary_motion[Global->auto_motion_direction], 1);
 }
 
 /* This decompiles and then recompiles all of the formulas of cells.
