@@ -1,7 +1,7 @@
 /*
- * $Id: cmd.c,v 1.19 2000/11/22 19:33:00 danny Exp $
+ * $Id: cmd.c,v 1.27 2001/02/14 20:54:50 danny Exp $
  *
- * Copyright  1993, 1999, 2000 Free Software Foundation, Inc.
+ * Copyright  1993, 1999, 2000, 2001 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,9 +91,9 @@ SELECT_TYPE write_pending_fd_set;
 /* Hooks for asynchronos i/o
  */
 
-struct select_hook file_read_hooks[SELECT_SET_SIZE] = {0};
-struct select_hook file_exception_hooks[SELECT_SET_SIZE] = {0};
-struct select_hook file_write_hooks[SELECT_SET_SIZE] = {0};
+struct select_hook file_read_hooks[SELECT_SET_SIZE] = {{0}};
+struct select_hook file_exception_hooks[SELECT_SET_SIZE] = {{0}};
+struct select_hook file_write_hooks[SELECT_SET_SIZE] = {{0}};
 
 int ioerror = 0;
 
@@ -419,28 +419,20 @@ select_hooks (void)
  * can do i/o or, until we timeout (timeout is specified in seconds,
  * 0 means block indefinately).  (Front end to select)
  */
-static void
-block_until_excitment (int timeout_seconds)
+void
+block_until_excitement(struct timeval *tv)
 {
   int ret;
-  struct timeval timeout;
-  struct timeval * time_p = 0;
 
-  if (timeout_seconds)
-    {
-      timeout.tv_sec = timeout_seconds;
-      timeout.tv_usec = 0;
-      time_p = &timeout;
-    }
   bcopy ((char *)&read_fd_set, (char *)&read_pending_fd_set,
-	 sizeof (SELECT_TYPE)) ;
+	 sizeof (SELECT_TYPE));
   bcopy ((char *)&exception_fd_set,
 	 (char *)&exception_pending_fd_set, sizeof (SELECT_TYPE));
   bcopy ((char *)&write_fd_set,
 	 (char *)&write_pending_fd_set, sizeof (SELECT_TYPE));
   ret = select (SELECT_SET_SIZE,
 		&read_pending_fd_set, &write_pending_fd_set,
-		&exception_pending_fd_set, time_p);
+		&exception_pending_fd_set, tv);
   if (ret < 0)
     {
       FD_ZERO (&read_pending_fd_set);
@@ -449,24 +441,24 @@ block_until_excitment (int timeout_seconds)
     }
 }
 
-/* This is the main interact loop.  As quickly as possible
+/*
+ * This is the main interact loop.  As quickly as possible
  * it returns a character from the keyboard.  While waiting,
  * it updates cells and the display.  If a macro is being defined,
  * this function save characters in the macro.
  */
-
 int 
 real_get_chr (void)
 {
+  int ret;
   unsigned int ch = EOF;		/* The char that will be returned. */
 
   /* Characters with the meta bit set are returned as
    * two characters: ESC and a non-meta character.
    * This buffers the non-meta character between calls.
-   * The value is 0 if no character is buffered, C+1 if
-   * C is buffered.
    */
-  static int saved_char;
+  static int	saved_char,
+		have_saved_char = 0;
 
   /* A buffer of characters read in one burst from the kbd. */
   static unsigned char ibuf[256];
@@ -474,86 +466,70 @@ real_get_chr (void)
   static int i_cnt;		/* buffer position */
 
   alarm_hooks ();
-  if (saved_char)
-    {
-      ch = saved_char - 1;
-      saved_char = 0;
+  if (have_saved_char) {
+      ch = saved_char;
+      have_saved_char = 0;
       goto fini;
     }
 
-  if (i_cnt)
-    {
+  if (i_cnt) {
       ch = ibuf[i_cnt++];
       if (i_cnt == i_in)
 	i_cnt = i_in = 0;
       goto fini;
-    }
+  }
 
   /* This loop until a character can be read. */
-  while (!io_input_avail ())
-    {
+  while (!io_input_avail ()) {
       alarm_hooks ();
       select_hooks ();
       io_scan_for_input (0);
-      if (!io_input_avail ())
-	{
-	  if (Global->auto_recalc && eval_next_cell ())
-	    {
-	      if (Global->bkgrnd_recalc)
-		while (!io_input_avail () && eval_next_cell ())
-		  io_scan_for_input (0);
-	      else
-		while (eval_next_cell ())
-		  ;
+      if (io_input_avail ())
+        break;
+      if (Global->auto_recalc && eval_next_cell ()) {
+	  if (Global->bkgrnd_recalc) {
+	    int loop = 0;
+	    while (!io_input_avail () && eval_next_cell () && ++loop < 10)
 	      io_scan_for_input (0);
-	      if (!io_input_avail ())
-		io_redisp ();
-	      io_flush ();
-	      io_scan_for_input (0);
-	    }
-	  else
-	    {
-	      int timeout = (Global->alarm_active
-			     ? (Global->alarm_seconds == 1
-				? 1
-				: (Global->alarm_seconds / 2))
-			     : 0);
-			     
-	      io_redisp ();
-	      io_flush ();
-	      io_scan_for_input (0);
-	      if (!io_input_avail ())
-		block_until_excitment (timeout);
-	    }
-	}
+	  } else
+	    while (eval_next_cell ())
+	      ;
+	  io_scan_for_input (0);
+	  if (!io_input_avail ())
+	    io_redisp ();
+	  io_flush ();
+	  io_scan_for_input (0);
+      } else {
+	  io_redisp ();
+	  io_flush ();
+	  io_scan_for_input (0);
+	  if (io_input_avail())
+	      break;
+	  if (!Global->alarm_active)
+	      block_until_excitement(0);
+	  else {
+	      struct timeval tv;
+	      tv.tv_sec = Global->alarm_seconds == 1 ? 1
+	        : Global->alarm_seconds / 2;
+	      tv.tv_usec = 0;
+	      block_until_excitement(&tv);
+	  }
+      }
     }
 
-  {
-    int ret;
     ret = io_read_kbd (ibuf, sizeof (ibuf));
-    if (ret == 1)
-      {
+    if (ret == 1) {
 	ch = ibuf[0];
-	goto fini;
-      }
-    if (ret > 1)
-      {
+    } else if (ret > 1) {
 	i_cnt = 1;
 	i_in = ret;
 	ch = ibuf[0];
-	goto fini;
-      }
-    if (ret == 0 || errno != EINTR)
-      return EOF;
-  }
+    } else if (ret == 0 || errno != EINTR) {
+	return EOF;
+    }
 
 fini:
-
-  if (ch & 0x80) {
-#if 0
-      saved_char = 1 + (ch & 0x7f);
-      ch = CTRL ('[');
-#else	/* SCANDI */
+  if (ch & META_BIT) {
 	switch (ch) {
 		case 229:                             /* e */
 		case 228:                             /* d */
@@ -563,32 +539,31 @@ fini:
 		case 214:                             /* V */
 			break;
 		default:
-			saved_char = 1 + (ch & 0x7f);
-			ch = CTRL ('[');
+			saved_char = ch;
+			have_saved_char = 1;
+			ch = CTRL_CHAR ('[');
 	}
-#endif
   }
 
-  if (making_macro)
-    {
+  if (making_macro) {
       /* This is stoopid and should be fixed.
        * Macros (and other cell strings) should be 
        * `struct line' and not c-strings.   -tl
        */
-      if (ch == 0)
-	*making_macro++ = 0x80 | 'a';
-      else if (ch == '{')
-	*making_macro++ = 0x80 | 'b';
-      else
+      if (ch == 0) {
+	*making_macro++ = SPECIAL_CODE_A;
+      } else if (ch == '{') {
+	*making_macro++ = SPECIAL_CODE_B;
+      } else {
 	*making_macro++ = ch;
-      if (making_macro >= (making_macro_start + making_macro_size))
-	{
+      }
+      if (making_macro >= (making_macro_start + making_macro_size)) {
 	  making_macro_start = ck_realloc (making_macro_start, 5
 					   + making_macro_size * 2);
 	  making_macro = (making_macro_start + making_macro_size);
 	  making_macro_size *= 2;
-	}
-    }
+      }
+  }
   return ch;
 }
 
@@ -766,7 +741,8 @@ remove_cmd_frame (struct command_frame * frame)
 }
 
 
-/* This frees all of the memory allocated to FRAME (including
+/*
+ * This frees all of the memory allocated to FRAME (including
  * the frame itself. 
  */
 void
@@ -792,8 +768,8 @@ free_cmd_frame (struct command_frame * frame)
   ck_free (frame);
 }
 
-
-/* Discard the current frame if it contains an unexecuted commnand. 
+/*
+ * Discard the current frame if it contains an unexecuted commnand. 
  * This is used, for example, to handle break.
  */
 void
@@ -821,7 +797,6 @@ pop_unfinished_command (void)
  * and cancels all pending macros.  This is properly followed by 
  * generating an error message for the user and longjmp to error_exception.
  */
-
 void
 recover_from_error (void)
 {
@@ -864,7 +839,8 @@ recover_from_error (void)
     }
 }
 
-/* When we begin editting a new argument, this function sets up the
+/*
+ * When we begin editting a new argument, this function sets up the
  * appropriate keymap, and then resets the state of the editting commands.
  *
  * The return value is 1 if the user must be prompted, 0 otherwise.
@@ -1040,7 +1016,6 @@ command_loop (int prefix, int iscmd)
        */
 
     prefix_cmd_continuation:
-
       /* In this loop, we look for the next command to
        * execute.  This may involve reading from a macro, 
        * or the keyboard.  If there is time to kill, updates
@@ -1049,8 +1024,7 @@ command_loop (int prefix, int iscmd)
        * This loop is exited by `goto got_command'.
        */
 
-      while (1)
-	{
+      while (1) {
 	  /* Get the next character.
 	   * However, if we are in a macro, and the next character
 	   * is '{', then the macro contains a function name
@@ -1059,18 +1033,13 @@ command_loop (int prefix, int iscmd)
 
 	get_next_char:
 
-	  if (pushed_back_char >= 0)
-	    {
+	  if (pushed_back_char >= 0) {
 	      ch = pushed_back_char;
 	      pushed_back_char = -1;
-	    }
-	  else if (!rmac)
-	    {
+	  } else if (!rmac) {
 	      io_fix_input ();
 	      ch = real_get_chr ();
-	    }
-	  else
-	    {
+	  } else {
 	      int len;
 	      unsigned char *ptr;
 	      
@@ -1085,14 +1054,14 @@ command_loop (int prefix, int iscmd)
 		  cur_chr = 0;
 		  goto got_command;
 		  
-		case 0x80 | 'a':
+		case SPECIAL_CODE_A:
 		  ch = '\0';
 		  break;
 		  
-		case 0x80 | 'b':
+		case SPECIAL_CODE_B:
 		  ch = '{';
 		  break;
-		case 0x80 | 'c':
+		case SPECIAL_CODE_C:
 		  ch = '}';
 		  break;
 		  
@@ -1155,10 +1124,10 @@ command_loop (int prefix, int iscmd)
 			    {
 			      switch (*ptr)
 				{
-				case 0x80 | 'b':
+				case SPECIAL_CODE_B:
 				  *ptr = '{';
 				  break;
-				case 0x80 | 'c':
+				case SPECIAL_CODE_C:
 				  *ptr = '}';
 				  break;
 				}
@@ -1173,45 +1142,43 @@ command_loop (int prefix, int iscmd)
 		    rmac->mac_exe += len + 1;
 		  goto got_command;
 		}
-	    }
+	  }
 
 	  /* When control comes here, adjust the keystate according 
 	   * to the cur_keymap and `ch';
 	   */
 	have_character:
-
 	  /* This is how keymaps are searched for a binding. */ 
-	  while (1)
-	    {
+	  while (1) {
 	      struct key * key;
 	      key = &(the_maps[cur_keymap]->keys[ch]);
-	      if (key->vector < 0)
-		{
-		  if (key->code >= 0)
-		    {
+#if 0
+	/* Debug keymap processing */
+	      fprintf(stderr, "Key %c Keymap %p (%s) code %d next %p\n",
+			ch, cur_keymap, map_names[cur_keymap],
+			key->code, the_maps[cur_keymap]->map_next);
+#endif
+	      if (key->vector < 0) {
+		  if (key->code >= 0) {
 		      cur_keymap = key->code;
 		      goto get_next_char;
-		    }
-		  else if (the_maps[cur_keymap]->map_next)
+		  } else if (the_maps[cur_keymap]->map_next) {
 		    cur_keymap =
 		      the_maps[cur_keymap]->map_next->id;
-		  else
-		    {
+		  } else {
 		      cur_vector = 0;
 		      cur_cmd = 0;
 		      cur_chr = ch;
 		      goto got_command;
-		    }
-		}
-	      else
-		{
+		  }
+	      } else {
 		  cur_vector = key->vector;
 		  cur_cmd =
 		    &(the_funcs[key->vector][key->code]);
 		  cur_chr = ch;
 		  goto got_command;
-		}
-	    }
+	      }
+	  }
 	}
 
       /* Now the next command to begin has been read from a macro
@@ -1301,7 +1268,7 @@ command_loop (int prefix, int iscmd)
        * the function interactively.
        */
       /* Whever a new command is encountered, we begin by creating a 
-       * frame in which to store it's arguments.
+       * frame in which to store its arguments.
        * This initializes the new frame on the basis of cur_cmd in 
        * the_cmd_frame.  
        */
@@ -1328,7 +1295,7 @@ command_loop (int prefix, int iscmd)
 	       * FUNC_ARGS string. To continue this loop, use `goto next_arg;'.
 	       *
 	       * If user interaction is required, the appropriate keymap,
-	       * editting area, etc. is set up, and the command loop resumes
+	       * editing area, etc. is set up, and the command loop resumes
 	       * (`goto new_cycle').
 	       */
 	      char * prompt = the_cmd_arg.arg_desc;
@@ -1795,7 +1762,7 @@ command_loop (int prefix, int iscmd)
 	  goto resume_getting_arguments;
 
       /* If this point is reached, call the interactive function,
-       * destroy it's frame, and restart the cycle.
+       * destroy its frame, and restart the cycle.
        */
       {
 	int move_cursor = 0;
@@ -1861,10 +1828,10 @@ quote_macro_args (args)
       switch (*args)
 	{
 	case '{':
-	  *args = 0x80 | 'b';
+	  *args = SPECIAL_CODE_B;
 	  break;
 	case '}':
-	  *args = 0x80 | 'c';
+	  *args = SPECIAL_CODE_C;
 	  break;
 	}
       ++args;
@@ -1988,11 +1955,11 @@ get_chr (void)
 	  --rmac->mac_exe;
 	  break;
 
-	case (0x80 | 'a'):
+	case (SPECIAL_CODE_A):
 	  ch = 0;
 	  break;
 
-	case (0x80 | 'b'):
+	case (SPECIAL_CODE_B):
 	  ch = '{';
 	  break;
 	default:
@@ -2242,7 +2209,7 @@ page_info_backwards (int rep)
     page_info (-rep);
   else if (the_cmd_frame->cmd && the_cmd_arg.prompt_info)
     {
-      int vis_lines = (scr_lines - input_rows) / info_rows;
+      int vis_lines = (Global->scr_lines - input_rows) / info_rows;
       int next = the_cmd_arg.info_line - vis_lines * rep;
       the_cmd_arg.info_line = ((next >= 0) ? next : 0);
     }
@@ -2260,7 +2227,7 @@ page_info (int rep)
     page_info_backwards (-rep);
   else if (the_cmd_frame->cmd && the_cmd_arg.prompt_info)
     {
-      int vis_lines = (scr_lines - input_rows) / info_rows;
+      int vis_lines = (Global->scr_lines - input_rows) / info_rows;
       int next = the_cmd_arg.info_line + vis_lines * rep;
       the_cmd_arg.info_line =
 	((next >= the_cmd_arg.prompt_info->len)
