@@ -2,9 +2,9 @@
 #define CMDH
 
 /*
- * $Id: cmd.h,v 1.5 2000/08/10 21:02:50 danny Exp $
+ * $Id: cmd.h,v 1.9 2001/02/14 19:22:57 danny Exp $
  *
- * Copyright  1992, 1993 Free Software Foundation, Inc.
+ * Copyright  1992, 1993, 2001 Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,6 +44,9 @@ struct alarm_entry
   time_t last_time;
 };
 
+#define	SPECIAL_CODE_A	0x80 + 'a'
+#define	SPECIAL_CODE_B	0x80 + 'b'
+#define	SPECIAL_CODE_C	0x80 + 'c'
 
 extern struct alarm_entry alarm_table[];
 
@@ -332,6 +335,7 @@ extern void end_macro (void);
 extern void stop_entering_macro (void);
 extern void store_last_macro (struct rng * rng);
 extern int real_get_chr (void);
+extern void block_until_excitement(struct timeval *tv);
 extern void push_command_frame (struct rng * rng, char * first_line, int len);
 extern void remove_cmd_frame (struct command_frame * frame);
 extern void free_cmd_frame (struct command_frame * frame);
