@@ -1,7 +1,7 @@
 /*
- * $Id: format.c,v 1.12 2000/08/10 21:02:50 danny Exp $
+ * $Id: format.c,v 1.14 2001/02/13 23:38:05 danny Exp $
  *
- * Copyright  1993 Free Software Foundation, Inc.
+ * Copyright  1993, 2001 Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,9 +99,13 @@ fmt_to_str (int format, int precision)
 char *
 cell_format_string(CELL *cp)
 {
+	static char no_default[] = "";
+
 	/* FIXME: Doesn't anything! */
 	if (cp == NULL)
 		return fmt_to_str(0, 0);
+	else
+		return no_default;
 
 	
 }
