@@ -1,24 +1,31 @@
-/*	Copyright (C) 1993 Free Software Foundation, Inc.
+/*
+ * $Id: forminfo.c,v 1.9 2000/08/10 21:02:50 danny Exp $
+ *
+ * Copyright  1993, 2000 Free Software Foundation, Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this software; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this software; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
-
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifdef	WITH_DMALLOC
+#include <dmalloc.h>
+#endif
+
 #include "sysdef.h"
 #include "forminfo.h"
 
@@ -72,7 +79,6 @@ char * formula_info[] =
 "			stores expressions in a byte-compiled form, excess",
 "			parens will mysteriously vanish.",
 0,
-
 
 	/* Error values. */
 
@@ -159,7 +165,6 @@ char * formula_info[] =
 "On some machines this may be indistinguishable from other values.",
 0,
 
-
 
 		/* Functions releated to boolean values. */
 
@@ -202,7 +207,6 @@ char * formula_info[] =
 "#TRUE if the VAL is a number, or can be automatically converted to a number.",
 "Thus `isnum(\"12\")' is #TRUE, while `isnum(\"dsfjbk\") is #FALSE.",
 0,
-
 
 	/* Functions that reflect the structure of the spreadsheet. */
 "row",
@@ -349,7 +353,6 @@ char * formula_info[] =
 "columns from the upper left corner of the range.",
 0,
 
-
 
 	/* General arithmetic*/
 
@@ -393,7 +396,6 @@ char * formula_info[] =
 0,
 
 
-
 
 "exp",
 "Exponential				exp(num)",
@@ -416,7 +418,6 @@ char * formula_info[] =
 "The square-root of NUM.",
 0,
 
-
 
 /* Trig functions */
 
@@ -490,7 +491,6 @@ char * formula_info[] =
 "Calling `hypot' may succeed in cases when the equivalent expression",
 "might underflow or overflow.",
 0,
-
 "oneof",
 "Case expression				oneof(choice,val1,val2,val3...)",
 "",
@@ -498,7 +498,6 @@ char * formula_info[] =
 "If CHOICE is not a valid integer in the appropriate range, the value is",
 "#OUT_OF_RANGE.  If no value arguments are supplied, the value is #NO_VALUES.",
 0,
-
 "sum",
 "Sum of values				sum(vr1, vr2, ...)",
 "",
@@ -527,7 +526,6 @@ char * formula_info[] =
 "provide a default value as an extra argument to product (e.g. `prod(1,",
 "r1:10c1)').",
 0,
-
 "avg",
 "Average					avg(vr1...)",
 "",
@@ -596,7 +594,6 @@ char * formula_info[] =
 "",
 "To get the sample variance, use std(...)^2",
 0,
-
   	/* string functions */
 "len",
 "String length				len(str)",
@@ -662,7 +659,6 @@ char * formula_info[] =
 "An argument may be a range, in which case the cell values in the range are",
 "concatenated.",
 0,
-
 
 	/* busy-ness functions */
 "pmt",
@@ -768,7 +764,6 @@ char * formula_info[] =
 "",
 "(undocumented -- documentation from volunteers welcome).",
 0, 
-
 			     /* Date functions */
 "hms_to_time",
 "hms_to_time(hours, minutes, seconds)",
@@ -991,7 +986,6 @@ char * formula_info[] =
 
 0,
 
-
 "help-with-help",
 "",
 "Valid help characters are:",
@@ -1019,6 +1013,49 @@ char * formula_info[] =
 "^W --  print-wallchart",
 "	Write a list of keybindings to a file.",
 0,
+#ifdef	HAVE_LIBPLOT
+"Plotutils-graphs",
+"",
+"[plotutils-presets-verbosely]	--  Reset graphing parameters to default values.",
+"[plotutils-clear-verbosely]	--  Clear the datasets of their assigned ranges.",
+"[plotutils-select-output]	--  Choose the output type for graphs.",
+"[plotutils-set-data]	--  Assign a range of data to a dataset in the graph.",
+"[plotutils-verify]	--  Verify graph parameters.",
+"[plotutils-plot]	--  Plot with the current parameters.",
+"",
+"[plotutils-x-axis]	--  Define parameters relating the X axis.",
+"[plotutils-y-axis]	--  Define parameters relating the Y axis.",
+"[plotutils-set-data-title]	--  Assign a title to a dataset.",
+"[plotutils-set-style]	--  Assign a style to a dataset.",
+"[plotutils-set-filename]	--  Set the file in which to store the graph.",
+"",
+"[plotutils-pie]	--  The graph should be a pie chart.",
+"[plotutils-bar]	--  The graph should be a bar chart.",
+"[plotutils-xy]	--  The graph should be a xy plot.",
+"",
+"Esc	--  End this command.",
+0,
+"plotutils-x-axis-help",
+"",
+"[plotutils-set-x-range-low]	--  Set the beginning of the range of the X axis.",
+"[plotutils-set-x-range-high]	--  Set the end of the range of the X axis.",
+"[plotutils-set-x-labels]	--  Provide labels for tic marks on the X axis.",
+"[plotutils-default-x-labels]	--  Use the default tic marks on the X axis.",
+"",
+"",
+"Esc	--  End this command.",
+0,
+"plotutils-y-axis-help",
+"",
+"[plotutils-set-y-range-low]	--  Set the beginning of the range of the Y axis.",
+"[plotutils-set-y-range-high]	--  Set the end of the range of the Y axis.",
+"[plotutils-set-y-labels]	--  Provide labels for tic marks on the Y axis.",
+"[plotutils-default-y-labels]	--  Use the default tic marks on the Y axis.",
+"",
+"Esc	--  End this command.",
+0,
+#else
+# ifdef WITH_GNUPLOT
 "graphing",
 "",
 "[graph-presets-verbosely]	--  Reset graphing parameters to default values.",
@@ -1057,14 +1094,24 @@ char * formula_info[] =
 "",
 "Esc	--  End this command.",
 0,
-"graph-output-types",
-"",
-#ifndef X_DISPLAY_MISSING
-"[graph-x11-mono]	--  Draw the graph in an X window, in black and white.",
-"[graph-x11-color]	--  Draw the graph in an X window, in color.",
+# endif
 #endif
-"[graph-postscript]	--  Write a file of postscript commands that draw that graph.",
+#ifdef	HAVE_LIBPLOT
+"plotutils-output-types",
+"",
+"[plotutils-postscript]	--  Write a file of postscript commands that draw that graph.",
+"[plotutils-tek]	--  Write a file of Tektronix terminal commands that draw that graph.",
+"[plotutils-regis]	--  Write a file of ReGIS terminal commands that draw that graph.",
+"[plotutils-pcl]	--  Write a file of PCL printer commands that draw that graph.",
+"[plotutils-hpgl]	--  Write a file of HP GL printer/plotter commands that draw that graph.",
+"[plotutils-illustrator]	--  Write a file in Adobe Illustrator format.",
+"[plotutils-metaplot]	--  Write a file GNU MetaPlot format.",
+"[plotutils-fig]	--  Write a file in the format of the FIG program.",
+"[plotutils-gif]	--  Write a file in GIF format.",
+"[plotutils-png]	--  Write a file in PNG format.",
 0,
+#else
+#endif
 "keybindings-wallchart",
 "",
 "			   General Utility",
@@ -1347,7 +1394,7 @@ char * formula_info[] =
 0,
 "_NON_WARRANTY_",
 "",
-" Copyright (C) 1990, 1991, 1992, 1997 Free Software Foundation,Inc.",
+" Copyright  1990, 1991, 1992, 1997 Free Software Foundation,Inc.",
 "There is ABSOLUTELY NO WARRANTY for Oleo; see the file COPYING",
 "for details.  Oleo is free software and you are welcome to distribute",
 "copies of it under certain conditions; see the file COPYING to see the",
@@ -1374,4 +1421,3 @@ forminfo_text (char * name)
       while (*pos++) ;
   return 0;
 }
-
