@@ -1,9 +1,9 @@
 #ifndef GLOBALH
 #define GLOBALH
 /*
- * $Id: global.h,v 1.15 2000/11/22 19:33:00 danny Exp $
+ * $Id: global.h,v 1.20 2001/02/14 20:54:50 danny Exp $
  *
- * Copyright  1990, 1992, 1993, 1999, 2000 Free Software Foundation, Inc.
+ * Copyright  1990, 1992, 1993, 1999, 2000, 2001 Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -148,7 +148,7 @@ typedef unsigned char CELLREF;
 #define PUT_COL(name,val)	((name)[1]=(val))
 #define EXP_ADD			sizeof(CELLREF)*2
 #else
-FOO FOO FOO You need to define the obvious macros above
+#error "FOO FOO FOO You need to define the obvious macros above"
 #endif
 #endif
 
@@ -349,8 +349,47 @@ struct OleoGlobal {
 	char				*encoding;
 	int				return_from_error;
 	int				had_error;
+
+	char				*oldLocale;
 };
 
 extern struct OleoGlobal *Global;
 
+/*
+ * Determine which flags are set to indicate META-key
+ *	OLEO_NUM_KEYS sizes a definition in key.h
+ */
+#define	BACKSPACE	0x7f
+
+#if 1
+/*
+ * Hopefully 8-bit clean version
+ */
+#ifndef CTRL_CHAR
+#define CTRL_CHAR(x)		((x)&037)
+#endif
+
+#define	META_BIT	0x8000			/* Must be power of 2 */
+#define	MASK_META_BIT	(META_BIT - 1)		/* used to be 0x7f */
+#define	OLEO_NUM_KEYS	0x10000
+
+#ifndef META
+#define META(X)		((X)|0200)
+#endif
+
+#else
+/* 8-bit diry version !! */
+
+#ifndef CTRL_CHAR
+#define CTRL_CHAR(x) (x&037)
+#endif
+#ifndef META
+#define META(X) ((X)|0200)
+#endif
+#define	META_BIT	0x80			/* Must be power of 2 */
+#define	MASK_META_BIT	(META_BIT - 1)		/* used to be 0x7f */
+
+#define	OLEO_NUM_KEYS	256
+#endif
+
 #endif	/* GLOBALH */
