@@ -1,7 +1,7 @@
 /*
- * $Id: init.c,v 1.7 2000/08/10 21:02:50 danny Exp $
+ * $Id: init.c,v 1.10 2001/02/14 19:22:57 danny Exp $
  *
- * Copyright  1993, 2000 Free Software Foundation, Inc.
+ * Copyright  1993, 2000, 2001 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
  * should not do any kind of io or cause errors.  If they do, you
  * will experience core dumps.
  */
-char *init_cmds[] =
+static char *init_cmds[] =
 {
   "",
   "# The keymap tree.",
@@ -47,7 +47,7 @@ char *init_cmds[] =
   "",
   "# This is the generic top-level keymap.   It should contain bindings that",
   "# apply at the top level keymap regardless of what mode the editor is in.",
-  "# All keymaps that are used at the top level should inerit from this.",
+  "# All keymaps that are used at the top level should inherit from this.",
   "create-keymap generic-main universal",
   "",
   "# This is the keymap in force at the top level when no command arguments are",
@@ -312,6 +312,7 @@ char *init_cmds[] =
   "",
   "bind-key read-string meta-read-string ^[",
   "bind-set read-string self-insert-command \\ -~",
+  "bind-set read-string self-insert-command -",
   "bind-key read-string exit-minibuffer ^m",
   "bind-key read-string beginning-of-line ^a",
   "bind-key read-string end-of-line ^e",
@@ -680,13 +681,8 @@ char *init_cmds[] =
 
 };
 
-#ifdef __STDC__
 void 
 run_init_cmds (void)
-#else
-void 
-run_init_cmds ()
-#endif
 {
   char **p = init_cmds;
   while (*p)
