@@ -1,7 +1,7 @@
 /*
- * $Id: io-term.c,v 1.45 2000/11/22 19:33:01 danny Exp $
+ * $Id: io-term.c,v 1.51 2001/02/13 23:38:06 danny Exp $
  *
- * Copyright  1990, 1992, 1993, 1999, 2000 Free Software Foundation, Inc.
+ * Copyright  1990, 1992, 1993, 1999, 2000, 2001 Free Software Foundation, Inc.
  * 
  * This file is part of Oleo, the GNU Spreadsheet.
  * 
@@ -20,7 +20,7 @@
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-static char *rcsid = "$Id: io-term.c,v 1.45 2000/11/22 19:33:01 danny Exp $";
+static char *rcsid = "$Id: io-term.c,v 1.51 2001/02/13 23:38:06 danny Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -86,6 +86,10 @@ static char *rcsid = "$Id: io-term.c,v 1.45 2000/11/22 19:33:01 danny Exp $";
 #include "panic.h"
 #endif
 
+#if	ENABLE_NLS
+extern char *gettext(char *);
+#endif
+
 /*
  * The ultimate global variable
  */
@@ -235,7 +239,7 @@ do_set_option (char *ptr)
 			*((int *)Preferences[i].var) = Preferences[i].value;
 
 		if (Preferences[i].cont == 0)
-			return;
+			return 1;
 		break;
 	}
 
@@ -571,7 +575,7 @@ read_mp_options (char *str)
   while ((np = (char *)index (str, ';')))
     {
       *np = '\0';
-      do_set_option (str);
+      (void) do_set_option (str);
       *np++ = ';';
       str = np;
     }
@@ -766,7 +770,7 @@ read_variables (FILE * fp)
     }
 }
 
-void
+static void
 init_maps (void)
 {
   num_maps = 0;
@@ -850,9 +854,10 @@ void InitializeGlobals(void)
   Global->topclear = 0;
   Global->alarm_seconds = 1;
   Global->alarm_active = 1;
+
   /* From window.c */
-  scr_lines = 24;
-  scr_cols = 80;
+  Global->scr_lines = 24;
+  Global->scr_cols = 80;
   user_input = 1;
   user_status = 2;
   Global->input = 0;
@@ -885,6 +890,8 @@ void InitializeGlobals(void)
 
   Global->mouse_id = 0;
 
+  Global->oldLocale = NULL;
+
   UserPreferences.run_load_hooks = 1;
   /* End initialize */
 
@@ -975,6 +982,9 @@ main (int argc, char **argv)
   volatile int init_fpc = 0;
   int command_line_file = 0;	/* was there one? */
 
+#if 0
+  sleep(30);
+#endif
 #if 1	/* ENABLE_NLS */
   setlocale(LC_ALL, "");
   bindtextdomain(PACKAGE, LOCALEDIR);
