@@ -1,9 +1,9 @@
 #undef	I18N_VERBOSE
-#undef	X_I18N
+#define	X_I18N
 /*
- * $Id: io-x11.c,v 1.25 2000/08/10 21:02:50 danny Exp $
+ * $Id: io-x11.c,v 1.31 2001/03/09 11:33:29 danny Exp $
  *
- *	Copyright  1992, 1993, 1999 Free Software Foundation, Inc.
+ *	Copyright  1992, 1993, 1999, 2000, 2001 Free Software Foundation, Inc.
  * 	
  * 	This program is free software; you can redistribute it and/or modify
  * 	it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #ifndef	HAVE_MOTIF
 #ifndef X_DISPLAY_MISSING
 
-#include  <stdio.h>
+#include <stdio.h>
 #include <ctype.h>
 #include <sys/param.h>
 #define NeedFunctionPrototypes 0
@@ -155,6 +155,8 @@ static KeySym RetKeySym;
 void
 get_x11_args (int * argc_p, char ** argv)
 {
+  char	*locale;
+
   XrmInitialize ();
   
 #if 0
@@ -176,7 +178,20 @@ get_x11_args (int * argc_p, char ** argv)
   if (!Global->io_x11_display_name)
     return;
   
-  setlocale(LC_ALL, "");	/* i18n */
+  locale = setlocale(LC_ALL, "");	/* i18n */
+#ifdef	I18N_VERBOSE
+  fprintf(stderr, "Setlocale() -> locale %s\n", locale);
+#endif
+
+  if (! XSupportsLocale()) {
+	fprintf(stderr, "X doesn't support this locale\n");
+	exit(0);
+  }
+  if (XSetLocaleModifiers("@im=none") == NULL) {
+	fprintf(stderr, "XSetLocaleModifiers failed\n");
+	exit(0);
+  }
+
   theDisplay = XOpenDisplay (Global->io_x11_display_name);
   if (!theDisplay)
     panic ("Can not connect to X.  Check your DISPLAY evironment variable.");
@@ -262,7 +277,7 @@ GetXIC(Display *theDisplay)
 {
 	XIMStyles	*xim_styles;
 	XIMStyle	input_style = 0;
-	char		*p, *buf, *b, *k;
+	char		*p;
 	int		i, j, found = 0;
 #if 0
 	XVaNestedList	list;
@@ -279,18 +294,22 @@ GetXIC(Display *theDisplay)
 		"OffTheSpot",
 		"Root",
 		"Root",
+		"Rxvt",
 		NULL
 	};
-	static char *preeditTypes = "OffTheSpot,OverTheSpot,Root";
 
 	static XIMStyle style_bits[] =
 	{
 	/* OverTheSpot */	XIMPreeditPosition | XIMStatusArea,
 	/* OffTheSpot */	XIMPreeditArea | XIMStatusArea,
 	/* Root */		XIMPreeditNothing | XIMStatusNothing,
-	/* Not really root */	XIMPreeditNone | XIMStatusNone
+	/* Not really root */	XIMPreeditNone | XIMStatusNone,
+	/* See rxvt */		XIMPreeditPosition | XIMStatusNothing,
 	};
 
+	/* FIX ME this should be user configurable such as in Motif */
+	static char *preeditTypes = "OffTheSpot,OverTheSpot,Root";
+
 	if (!XSupportsLocale()) {
 #ifdef	I18N_VERBOSE
 		fprintf(stderr, "X doesn't support this locale\n");
@@ -327,7 +346,7 @@ GetXIC(Display *theDisplay)
 	/* Match input styles between X server + input method and ourselves */
 	for (i = 0, found = False; styles[i] && !found; i++) {
 #ifdef	I18N_VERBOSE
-		fprintf(stderr, "Trying %s (0x%X)\n", styles[i], style_bits[i]);
+		fprintf(stderr, "Trying %s (0x%lx)\n", styles[i], style_bits[i]);
 #endif
 
 		if (strstr(preeditTypes, styles[i]) == 0) {
@@ -342,55 +361,19 @@ GetXIC(Display *theDisplay)
 		}
 	}
 
-#if 0
-	fontset = XCreateFontSet(theDisplay,
-		"-adobe-helvetica-*-r-*-*-*-120-*-*-*-*-*-*,\
-		-misc-fixed-*-r-*-*-*-130-*-*-*-*-*-*",
-		&missing_charsets, &num_missing_charsets, &default_string);
-
-	if (num_missing_charsets > 0) {
-		fprintf(stderr, PACKAGE " : the %d missing charsets\n", num_missing_charsets);
-		for (i=0; i<num_missing_charsets; i++)
-			fprintf(stderr, "\t%d - %s\n", i, missing_charsets[i]);
-	}
-
-	list = XVaCreateNestedList(0,XNFontSet,fontset,NULL);
-#endif
-
 	xic = XCreateIC(xim,
 			XNInputStyle,		input_style,
 			XNClientWindow,		thePort->window,
 			XNFocusWindow,		thePort->window,
-#if 0
-			XNPreeditAttributes,	list,
-			XNStatusAttributes,	list,
-#endif
 		NULL);
 
-#if 0
-	XFree(list);
-#endif
-
 #ifdef	I18N_VERBOSE
 	if (xic)
-		fprintf(stderr, "We have an IC\n");
+		fprintf(stderr, "We have an IC - input style %x window %p\n",
+			input_style, thePort->window);
 	else
 		fprintf(stderr, "No IC\n");
 #endif
-
-#if 0
-	/* UGLY HACK !!! */
-
-	XGetICValues(xic, XNFilterEvents, &mask, NULL);
-#ifdef	I18N_VERBOSE
-	fprintf(stderr, "Mask is 0x%X\n", mask);
-#endif
-
-	XSelectInput(theDisplay, thePort->window,
-		ExposureMask | KeyPressMask | StructureNotifyMask | mask);
-
-	XSetICFocus(xic);
-#endif
 }
 
 static void
@@ -606,7 +589,7 @@ xio_redraw_input (void)
 	    text.chars = iv->expanded_keymap_prompt;
 	    text.nchars = strlen (iv->expanded_keymap_prompt);
 	    xdraw_text_item (thePort,
-			    0, ypos, scr_cols, input_rows,
+			    0, ypos, Global->scr_cols, input_rows,
 			    thePort->input_font, thePort->input_gc,
 			    &text, 0);
 	    iv->redraw_needed = NO_REDRAW;
@@ -630,7 +613,7 @@ xio_redraw_input (void)
       {
 	XFillRectangle (thePort->dpy, thePort->window, thePort->neutral_gc,
 			iv->prompt_wid, ypos,
-			scr_cols - iv->prompt_wid, input_rows);
+			Global->scr_cols - iv->prompt_wid, input_rows);
 	iv->redraw_needed = NO_REDRAW;
 	return;
       }
@@ -646,7 +629,7 @@ xio_redraw_input (void)
 		    + XTextWidth (thePort->input_font,
 				  iv->input_area->buf + iv->visibility_begin,
 				  pos - iv->visibility_begin));
-	int wid = scr_cols - xpos;
+	int wid = Global->scr_cols - xpos;
 	int hgt = input_rows;
 
 	XTextItem text;
@@ -740,112 +723,38 @@ static Status compose;
 static void
 xio_scan_for_input (int blockp)
 {
-  XEvent event_return;
-  static int pendingw;
-  static int pendingh;
-  static int resize_pending = 0;
-  int events_pending;
-  int len;
-  
-  events_pending = XPending (thePort->dpy);
-  do
-    {
-      if (resize_pending && !events_pending)
-	{
-	  if (   ((pendingh / Global->height_scale) > 9.)
-	      && ((pendingw / Global->width_scale) > 9.))
-	      {
+    XEvent event_return;
+    static int pendingw;
+    static int pendingh;
+    static int resize_pending = 0;
+    int events_pending;
+    int len;
+
+    events_pending = XPending (thePort->dpy);
+    do {
+	if (resize_pending && !events_pending) {
+	  if (((pendingh / Global->height_scale) > 9.)
+			&& ((pendingw / Global->width_scale) > 9.)) {
 		io_set_scr_size (pendingh, pendingw);
 		resize_pending = 0;
-	      }
-	}
-      
-      if (!events_pending)
-	io_redisp ();
-      
-      if (events_pending || blockp)
-	{
-	  XNextEvent (thePort->dpy, &event_return);
-
-          if (event_return.xany.send_event)
-	    {
-	      /*
-	       * Allow other XClients to send oleo commands.
-	       */
-	      static KeySym se_keysym;
-
-	      switch (event_return.type)
-                {
-		case FocusIn:
-			xi18nGetFocus();
-			break;
-
-		case FocusOut:
-			xi18nLoseFocus();
-			break;
-
-	          case KeyPress:
-                    /* Put keypress send_events aside until a <Return>. */
-	            if (se_chars_buffered + MAX_KEY_TRANSLATION 
-			  >= se_buf_allocated)
-	              {
-	                se_buf_allocated =
-		          2 * (se_buf_allocated
-		            ? se_buf_allocated
-		            : MAX_KEY_TRANSLATION);
-	                se_buf =
-		          (char *) ck_remalloc (se_buf, se_buf_allocated);
-	              }
-#if 0
-	            len = XLookupString (&event_return,
-			           se_buf + se_chars_buffered,
-			           MAX_KEY_TRANSLATION, &se_keysym, &compose);
-#else
-		    len = xi18nlookup(&event_return, se_buf + se_chars_buffered,
-				MAX_KEY_TRANSLATION, &se_keysym, &compose);
-#endif
-
-	            if ((len == 1) && (event_return.xkey.state & Mod1Mask))
-	              se_buf[se_chars_buffered] |= 0x80;
-
-	            if (se_keysym == RetKeySym)
-                      {
-			jmp_buf tmp_exception;
-
-			bcopy(Global->error_exception, tmp_exception, sizeof(jmp_buf));
-		        se_buf[se_chars_buffered] = '\0';
-
-			if (setjmp (Global->error_exception))
-			  {
-			    fprintf(stderr, "Error in send_event command: %s\n", se_buf);
-			    se_buf[0] = '\0';
-			    se_chars_buffered = 0;
-			    set_info (0);
-		            pop_unfinished_command ();
-			    bcopy(tmp_exception, Global->error_exception, sizeof(jmp_buf));
-			    longjmp (Global->error_exception, 1); /**/
-			  }
-			else
-			  {
-			    execute_command (se_buf);
-			    bcopy(tmp_exception, Global->error_exception, sizeof(jmp_buf));
-			  }
-		        se_buf[0] = '\0';
-		        se_chars_buffered = 0;
-                      }
-		    else
-		      se_chars_buffered += len;
-	            break;
-	        }
-              events_pending = XPending (thePort->dpy);
-	      continue;
-            }
 	  }
-      else
-	return;
+	}
+
+	if (!events_pending)
+		io_redisp ();
       
-      switch (event_return.type)
-	{
+	if (events_pending || blockp) {
+	    XNextEvent (thePort->dpy, &event_return);
+	    if (XFilterEvent(&event_return, None))
+		continue;
+
+	    if (event_return.xany.send_event) {
+		/*
+		 * Allow other XClients to send oleo commands.
+		 */
+		static KeySym se_keysym;
+
+		switch (event_return.type) {
 		case FocusIn:
 			xi18nGetFocus();
 			break;
@@ -854,76 +763,119 @@ xio_scan_for_input (int blockp)
 			xi18nLoseFocus();
 			break;
 
+		case KeyPress:
+			/* Put keypress send_events aside until a <Return>. */
+			if (se_chars_buffered + MAX_KEY_TRANSLATION >= se_buf_allocated) {
+				se_buf_allocated = 2 * (se_buf_allocated ?
+					se_buf_allocated : MAX_KEY_TRANSLATION);
+				se_buf = (char *)ck_remalloc(se_buf, se_buf_allocated);
+			}
+			len = xi18nlookup(&event_return, se_buf + se_chars_buffered,
+				MAX_KEY_TRANSLATION, &se_keysym, &compose);
+
+			if ((len == 1) && (event_return.xkey.state & Mod1Mask))
+				se_buf[se_chars_buffered] |= META_BIT;
+
+			if (se_keysym == RetKeySym) {
+				jmp_buf tmp_exception;
+
+				bcopy(Global->error_exception, tmp_exception, sizeof(jmp_buf));
+				se_buf[se_chars_buffered] = '\0';
+
+				if (setjmp (Global->error_exception)) {
+					fprintf(stderr, "Error in send_event command: %s\n", se_buf);
+					se_buf[0] = '\0';
+					se_chars_buffered = 0;
+					set_info (0);
+					pop_unfinished_command ();
+					bcopy(tmp_exception, Global->error_exception,
+						sizeof(jmp_buf));
+					longjmp (Global->error_exception, 1); /**/
+				} else {
+					execute_command (se_buf);
+					bcopy(tmp_exception, Global->error_exception,
+						sizeof(jmp_buf));
+				}
+				se_buf[0] = '\0';
+				se_chars_buffered = 0;
+			} else {
+				se_chars_buffered += len;
+			}
+			break;
+		}
+		events_pending = XPending (thePort->dpy);
+		continue;
+	    }
+	} else {
+		return;
+	}
+
+	switch (event_return.type) {
+	case FocusIn:
+		xi18nGetFocus();
+		break;
+
+	case FocusOut:
+		xi18nLoseFocus();
+		break;
+
 	case ClientMessage:
-	  if (event_return.xclient.data.l[0] == thePort->wm_delete_window)
-	    {
-	      XCloseDisplay(thePort->dpy);
-	      exit(0);
-	    }
-	  break;
+		if (event_return.xclient.data.l[0] == thePort->wm_delete_window) {
+			XCloseDisplay(thePort->dpy);
+			exit(0);
+		}
+		break;
+
 	case KeyPress:
 	case ButtonPress:
 	case ButtonRelease:
-	  if (chars_buffered + MAX_KEY_TRANSLATION >= input_buf_allocated)
-	    {
-	      input_buf_allocated =
-		2 * (input_buf_allocated
-		     ? input_buf_allocated
-		     : MAX_KEY_TRANSLATION);
-	      input_buf =
-		(char *) ck_remalloc (input_buf, input_buf_allocated);
-	    }
+		if (chars_buffered + MAX_KEY_TRANSLATION >= input_buf_allocated) {
+			input_buf_allocated = 2 * (input_buf_allocated ? input_buf_allocated
+				: MAX_KEY_TRANSLATION);
+			input_buf = (char *)ck_remalloc(input_buf, input_buf_allocated);
+		}
 	}
- 
-      switch (event_return.type)
-	{
+
+	switch (event_return.type) {
 	case KeyPress:
-#if 0
-	  len = XLookupString (&event_return,
-			       input_buf + chars_buffered,
-			       MAX_KEY_TRANSLATION, 0, &compose);
-#else
-	  len = xi18nlookup(&event_return,input_buf + chars_buffered,
-				MAX_KEY_TRANSLATION, 0, &compose);
-#endif
-	  if ((len == 1) && (event_return.xkey.state & Mod1Mask))
-	    input_buf[chars_buffered] |= 0x80;
-	  chars_buffered += len;
-	  break;
+		len = xi18nlookup(&event_return,input_buf + chars_buffered,
+			MAX_KEY_TRANSLATION, 0, &compose);
+		if ((len == 1) && (event_return.xkey.state & Mod1Mask))
+			input_buf[chars_buffered] |= META_BIT;
+		chars_buffered += len;
+		break;
 	  
 	case ButtonPress:
 	case ButtonRelease:
-	  {
-	    int seq =
-	      enqueue_mouse_event (event_return.xbutton.y,
-				   event_return.xbutton.x,
-				   event_return.xbutton.button,
-				   event_return.type == ButtonPress);
-	    input_buf[chars_buffered++] = MOUSE_CHAR;
-	    input_buf[chars_buffered++] =
-	      event_return.xbutton.button - 1 + '0';
-	    input_buf[chars_buffered++] = (char) seq;
-	    break;
-	  }
+	{
+		int seq = enqueue_mouse_event (event_return.xbutton.y,
+				event_return.xbutton.x,
+				event_return.xbutton.button,
+				event_return.type == ButtonPress);
+		input_buf[chars_buffered++] = MOUSE_CHAR;
+		input_buf[chars_buffered++] = event_return.xbutton.button - 1 + '0';
+		input_buf[chars_buffered++] = (char) seq;
+		break;
+	}
 	  
 	case Expose:
-	  record_damage (thePort,
-			 event_return.xexpose.x, event_return.xexpose.y,
-			 event_return.xexpose.width,
-			 event_return.xexpose.height);
-	  break;
+		record_damage (thePort,
+			event_return.xexpose.x, event_return.xexpose.y,
+			event_return.xexpose.width,
+			event_return.xexpose.height);
+		break;
 	  
 	case MapNotify:
-	  break;
+		break;
 	  
 	case ReparentNotify:
-	  break;
+		break;
 	  
 	case ConfigureNotify:
-	  pendingw = event_return.xconfigure.width;
-	  pendingh = event_return.xconfigure.height;
-	  resize_pending = 1;
-	  break;
+		pendingw = event_return.xconfigure.width;
+		pendingh = event_return.xconfigure.height;
+		resize_pending = 1;
+		break;
 	  
 	case FocusIn:
 		xi18nGetFocus();
@@ -934,7 +886,7 @@ xio_scan_for_input (int blockp)
 		break;
 
 	default:
-	  break;
+		break;
 	}
       events_pending = XPending (thePort->dpy);
     }
@@ -1047,11 +999,11 @@ draw_input (void)
   if (!input_text.chars)
     {
       XFillRectangle (thePort->dpy, thePort->window, thePort->neutral_gc,
-		      Global->input, 0, scr_cols, input_rows);
+		      Global->input, 0, Global->scr_cols, input_rows);
       return;
     }
   input_text.font = thePort->input_font->fid;
-  xdraw_text_item (thePort, 0, Global->input, scr_cols, input_rows, thePort->input_font,
+  xdraw_text_item (thePort, 0, Global->input, Global->scr_cols, input_rows, thePort->input_font,
 		  thePort->input_gc, &input_text, 1);
   if (input_more_mode)
     {
@@ -1061,7 +1013,7 @@ draw_input (void)
       more_text.nchars = 6;
       more_text.delta = 0;
       more_text.font = thePort->input_font->fid;
-      xdraw_text_item (thePort, scr_cols - mwid, Global->input, mwid, input_rows,
+      xdraw_text_item (thePort, Global->scr_cols - mwid, Global->input, mwid, input_rows,
 		      thePort->input_font, thePort->standout_input_gc,
 		      &more_text, 1);
     }
@@ -1134,7 +1086,7 @@ xdraw_status (void)
   if (!x11_opened || thePort->input_view.current_info)
     return;
   if (user_status)
-    xdraw_text_item (thePort, 0, Global->status, scr_cols,
+    xdraw_text_item (thePort, 0, Global->status, Global->scr_cols,
 		    status_rows, thePort->status_font,
 		    thePort->status_gc, &status_text, 1);
 }
@@ -1212,7 +1164,7 @@ xio_update_status (void)
     int wid;
     
     l = strlen (ptr);
-    c = cram (scr_cols - mplen - thePort->status_font->max_bounds.width,
+    c = cram (Global->scr_cols - mplen - thePort->status_font->max_bounds.width,
 	      thePort->status_font, ptr, l, (dec ? " [...]" : "..."));
     if (c)
       bcopy (ptr, pos, c);
@@ -1238,7 +1190,7 @@ xio_update_status (void)
     if (dec)
       {
 	l = strlen (dec);
-	c = cram (scr_cols - wid, thePort->status_font, dec, l, "[...]");
+	c = cram (Global->scr_cols - wid, thePort->status_font, dec, l, "[...]");
 	*pos++ = '[';
 	if (c < l)
 	  {
@@ -1913,8 +1865,8 @@ draw_labels (void)
 	
 	rect.x = 0;
 	rect.y = 0;
-	rect.width = scr_cols;
-	rect.height = scr_lines;
+	rect.width = Global->scr_cols;
+	rect.height = Global->scr_lines;
 	XSetClipRectangles (thePort->dpy, thePort->label_standout_gc,
 			    0, 0, &rect, 1, YXBanded);
 	{
@@ -1965,8 +1917,8 @@ draw_labels (void)
 	    }
 	  rect.x = 0;
 	  rect.y = 0;
-	  rect.width = scr_cols;
-	  rect.height = scr_lines;
+	  rect.width = Global->scr_cols;
+	  rect.height = Global->scr_lines;
 	  XSetClipRectangles (thePort->dpy, thePort->label_standout_gc,
 			      0, 0, &rect, 1, YXBanded);
 	  
@@ -2034,7 +1986,7 @@ xio_redisp (void)
       if (thePort->input_view.info_redraw_needed)
 	{
 	  int ipos = thePort->input_view.info_pos;
-	  int top = ipos + (scr_lines - input_rows) / info_rows - 1;
+	  int top = ipos + (Global->scr_lines - input_rows) / info_rows - 1;
 	  int ypos;
 	  XTextItem text;
 
@@ -2048,7 +2000,7 @@ xio_redisp (void)
 	    {
 	      text.chars = thePort->input_view.current_info->text[ipos];
 	      text.nchars = strlen (text.chars);
-	      xdraw_text_item (thePort, 0, ypos, scr_cols, input_rows,
+	      xdraw_text_item (thePort, 0, ypos, Global->scr_cols, input_rows,
 			      thePort->text_line_font, thePort->text_line_gc,
 			      &text, 0);
 	      ypos += info_rows;
@@ -2056,7 +2008,7 @@ xio_redisp (void)
 	    }
 	  XFillRectangle (thePort->dpy, thePort->window,
 			  thePort->neutral_gc, 0, ypos,
-			  scr_cols, scr_lines - ypos - 1);
+			  Global->scr_cols, Global->scr_lines - ypos - 1);
 	  thePort->input_view.redraw_needed = FULL_REDRAW;
 	  xio_redraw_input ();
 	  thePort->input_view.info_redraw_needed = 0;
@@ -2420,7 +2372,7 @@ xio_open_display (void)
 	    char string[10];
 	    KeyCode *tmpptr;
 	    int *modptr;
-	    int idx, i, n ;
+	    int i, n;
 
 	    /* Build list of appropriate KeyCodes */
 	    n = 0;
@@ -2528,7 +2480,7 @@ set_x_default_point_size (int l)
 	Global->height_scale = cgc->font->ascent + cgc->font->descent;
 	Global->width_scale = cgc->font->max_bounds.width;
       }
-      io_set_scr_size (scr_lines, scr_cols);
+      io_set_scr_size (Global->scr_lines, Global->scr_cols);
     }
 }
 
