@@ -1,7 +1,7 @@
 /*
- * $Id: oleofile.c,v 1.24 2000/11/22 19:33:01 danny Exp $
+ * $Id: oleofile.c,v 1.26 2001/02/13 23:38:06 danny Exp $
  *
- * Copyright  1990-2000 Free Software Foundation, Inc.
+ * Copyright  1990-2000, 2001 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1063,10 +1063,10 @@ oleo_write_file (fp, rng)
   /* Axis tick marks */
   fprintf(fp, "Gm0%c%s\n",
 	'0' + graph_get_axis_ticktype(0),
-	graph_get_axis_tickformat(0));
+	graph_get_axis_tickformat(0) ? graph_get_axis_tickformat(0) : "(null)");
   fprintf(fp, "Gm1%c%s\n",
 	'0' + graph_get_axis_ticktype(1),
-	graph_get_axis_tickformat(1));
+	graph_get_axis_tickformat(1) ? graph_get_axis_tickformat(1) : "(null)");
 
   /* Database stuff */
   if (DatabaseInitialised()) {
