@@ -1,9 +1,9 @@
 /*
- *  $Id: pcl.c,v 1.15 2000/08/10 21:02:51 danny Exp $
+ *  $Id: pcl.c,v 1.17 2001/02/13 23:38:06 danny Exp $
  *
  *  This file is part of Oleo, the GNU spreadsheet.
  *
- *  Copyright  1999 by the Free Software Foundation, Inc.
+ *  Copyright  1999, 2000, 2001 by the Free Software Foundation, Inc.
  *  Written by Danny Backx <danny@gnu.org>.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-static char rcsid[] = "$Id: pcl.c,v 1.15 2000/08/10 21:02:51 danny Exp $";
+static char rcsid[] = "$Id: pcl.c,v 1.17 2001/02/13 23:38:06 danny Exp $";
 
 #include <stdio.h>
 
@@ -129,9 +129,6 @@ void PCLPageFooter(char *str, FILE *fp)
 void PCLField(char *str, int wid, int rightborder,
 			int xpoints, int xchars, FILE *fp)
 {
-	char	format[16];
-	int	l;
-
 #if 0
 	fprintf(stderr, "PCLField(%s,%d,%d)\n",
 		str, wid, rightborder);
