@@ -1,7 +1,7 @@
 /*
- * $Id: plot.c,v 1.26 2000/11/22 19:33:01 danny Exp $
+ * $Id: plot.c,v 1.28 2001/02/13 23:38:06 danny Exp $
  *
- * Copyright  1998-2000 Free Software Foundation, Inc.
+ * Copyright  1998, 1999, 2000, 2001 Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: plot.c,v 1.26 2000/11/22 19:33:01 danny Exp $
+ * $Id: plot.c,v 1.28 2001/02/13 23:38:06 danny Exp $
  *
  * This file contains the code to draw plots from the Oleo data
  * layered on top of the libsciplot functions.
@@ -81,18 +81,6 @@ struct PlotutilsDevices PlotutilsDeviceArray[] = {
 
 #include <stdarg.h>
 
-static void OleoLog(char *fmt, ...)
-{
-	va_list	ap;
-	FILE	*log = fopen("/tmp/oleolog", "a");
-	if (log) {
-		va_start(ap, fmt);
-		vfprintf(log, fmt, ap);
-		va_end(ap);
-		fclose(log);
-	}
-}
-
 typedef void (*sh) (int);
 sh	oldsig;
 
