@@ -1,9 +1,9 @@
 /*
- *  $Id: postscript.c,v 1.17 2000/08/10 21:02:51 danny Exp $
+ *  $Id: postscript.c,v 1.20 2001/02/13 23:38:06 danny Exp $
  *
  *  This file is part of Oleo, the GNU spreadsheet.
  *
- *  Copyright  1999 by the Free Software Foundation, Inc.
+ *  Copyright  1999, 2000, 2001 by the Free Software Foundation, Inc.
  *  Written by Danny Backx <danny@gnu.org>.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
  * There shouldn't be much spreadsheet functionality here...
  */
 
-static char rcsid[] = "$Id: postscript.c,v 1.17 2000/08/10 21:02:51 danny Exp $";
+static char rcsid[] = "$Id: postscript.c,v 1.20 2001/02/13 23:38:06 danny Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -40,6 +40,8 @@ static char rcsid[] = "$Id: postscript.c,v 1.17 2000/08/10 21:02:51 danny Exp $"
 
 #include <stdio.h>
 #include <ctype.h>
+#include <locale.h>
+
 #include "display.h"
 #include "font.h"
 #include "global.h"
@@ -111,6 +113,9 @@ void PostScriptJobHeader(char *title, int npages, FILE *fp)
 	struct font_names	*fn;
 	struct font_memo	*fm;
 
+	if (! Global->oldLocale)
+		Global->oldLocale = setlocale(LC_ALL, NULL);
+
 	FontCacheRestart();
 
 	fprintf(fp, "%%!PS-Adobe-3.0\n");
@@ -175,6 +180,8 @@ void PostScriptJobTrailer(int npages, FILE *fp)
 {
 	fprintf(fp, "%%Pages: %d\n", npages);
 	fprintf(fp, "%%EOF\n");
+
+	setlocale(LC_ALL, Global->oldLocale);
 }
 
 /*
@@ -212,16 +219,11 @@ void PostScriptPageFooter(char *str, FILE *fp)
 void PostScriptField(char *str, int wid, int rightborder,
 			int xpoints, int xchars, FILE *fp)
 {
-	float	w;
-
 #if 0
 	fprintf(stderr, "PostScriptField(%s, wid %d, xpoints %d)\n",
 			str, wid, xpoints);
 #endif
 	if (strlen(str)) {
-		float	tw = strlen(str) * CurrentFontSize;
-
-
 		fprintf(fp, "%3.1f %3.1f moveto ", border_width + xpoints, y);
 
 		put_ps_string(str, fp);
