@@ -1,27 +1,36 @@
-/*	Copyright (C) 1990, 1992, 1993 Free Software Foundation, Inc.
-
-This file is part of Oleo, the GNU Spreadsheet.
-
-Oleo is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-Oleo is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Oleo; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+/*
+ * $Id: sylk.c,v 1.18 2000/08/10 21:02:51 danny Exp $
+ *
+ * Copyright  1990, 1992, 1993 Free Software Foundation, Inc.
+ * 
+ * This file is part of Oleo, the GNU Spreadsheet.
+ * 
+ * Oleo is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * Oleo is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with Oleo; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifdef	WITH_DMALLOC
+#include <dmalloc.h>
+#endif
+
 #include "funcdef.h"
 #include <stdio.h>
+#include <ctype.h>
 #include "sysdef.h"
 #include "io-generic.h"
 #include "io-abstract.h"
@@ -43,15 +52,14 @@ static char * sylk_to_oleo_functions(char *f);
 
 #define	SYLK_LEN	1024
 
-int	nformat = 0;		/* We've already read this many formats */
+/* FIX ME Where does this variable belong ?? */
+static int	nformat = 0;		/* We've already read this many formats */
 /*
  * These functions read and write Microsoft Multiplan SYLK style files
  * as well as SYLK-NOA0 files.  SYLK-NOA0 is the same as SYLK except that
  * cell references are in rc format instead of a0 format.
  */
 
-int sylk_a0 = 1;		/* Determines sylk vs. sylk_noa0 format. */
-
 void
 sylk_read_file (fp, ismerge)
      FILE *fp;
@@ -75,9 +83,9 @@ sylk_read_file (fp, ismerge)
   int old_a0;
   int	num;
 
-  old_a0 = a0;
+  old_a0 = Global->a0;
   next_a0 = old_a0;
-  a0 = sylk_a0;
+  Global->a0 = Global->sylk_a0;
 
   lineno = 0;
   if (!ismerge)
@@ -558,7 +566,7 @@ sylk_read_file (fp, ismerge)
 	/* First character on the line */
 	case 'O':
 	  /* JF extension: read uset-settable options */
-	  a0 = next_a0;
+	  Global->a0 = next_a0;
 
 #if 0
 	/* FIX ME
@@ -567,14 +575,14 @@ sylk_read_file (fp, ismerge)
 	 */
 	  read_mp_options (ptr + 2);
 #endif
-	  next_a0 = a0;
-	  a0 = sylk_a0;
+	  next_a0 = Global->a0;
+	  Global->a0 = Global->sylk_a0;
 	  break;
 
 	/* First character on the line */
 	default:
 	bad_field:
-	  a0 = old_a0;
+	  Global->a0 = old_a0;
 	  if (!ismerge)
 	    clear_spreadsheet ();
 	  io_recenter_all_win ();
@@ -589,7 +597,7 @@ sylk_read_file (fp, ismerge)
 		break;
 	}
     }
-  a0 = next_a0;
+  Global->a0 = next_a0;
   io_recenter_all_win ();
 }
 
@@ -772,8 +780,8 @@ sylk_write_file (fp, rng)
 
     }
 
-  old_a0 = a0;
-  a0 = sylk_a0;
+  old_a0 = Global->a0;
+  Global->a0 = Global->sylk_a0;
 
   find_widths (rng->lc, rng->hc);
   w = next_width (&c);
@@ -902,7 +910,7 @@ sylk_write_file (fp, rng)
     write_mp_windows (fp);
 
   (void) fprintf (fp, "E\n");
-  a0 = old_a0;
+  Global->a0 = old_a0;
 }
 
 int
